@@ -12,7 +12,8 @@ module Hledger.UI.AccountsScreen
 where
 
 import Brick
-import Brick.Widgets.List hiding (reverse)
+import Brick.Widgets.List
+  (handleListEvent, list, listElementsL, listMoveDown, listMoveTo, listNameL, listSelectedElement, listSelectedL, renderList)
 import Brick.Widgets.Edit
 import Control.Monad
 import Control.Monad.IO.Class (liftIO)
@@ -40,6 +41,7 @@ import Hledger.UI.Editor
 import Hledger.UI.RegisterScreen
 import Hledger.UI.ErrorScreen
 
+
 accountsScreen :: Screen
 accountsScreen = AccountsScreen{
    sInit   = asInit
@@ -122,10 +124,10 @@ asInit _ _ _ = error "init function called with wrong screen type, should not ha
 
 asDraw :: UIState -> [Widget Name]
 asDraw UIState{aopts=uopts@UIOpts{cliopts_=copts@CliOpts{reportopts_=ropts}}
-                           ,ajournal=j
-                           ,aScreen=s@AccountsScreen{}
-                           ,aMode=mode
-                           } =
+              ,ajournal=j
+              ,aScreen=s@AccountsScreen{}
+              ,aMode=mode
+              } =
   case mode of
     Help       -> [helpDialog copts, maincontent]
     -- Minibuffer e -> [minibuffer e, maincontent]
@@ -173,19 +175,12 @@ asDraw UIState{aopts=uopts@UIOpts{cliopts_=copts@CliOpts{reportopts_=ropts}}
 
         toplabel =
               withAttr ("border" <> "filename") files
-          -- <+> withAttr ("border" <> "query") (str (if flat_ ropts then " flat" else ""))
-          <+> nonzero
-          <+> str (if ishistorical then " accounts" else " account changes")
-          -- <+> str (if ishistorical then " balances" else " changes")
+          <+> toggles
+          <+> str (" account " ++ if ishistorical then "balances" else "changes")
           <+> borderPeriodStr (if ishistorical then "at end of" else "in") (period_ ropts)
           <+> borderQueryStr querystr
-          <+> togglefilters
           <+> borderDepthStr mdepth
-          <+> str " ("
-          <+> cur
-          <+> str "/"
-          <+> total
-          <+> str ")"
+          <+> str (" ("++curidx++"/"++totidx++")")
           <+> (if ignore_assertions_ $ inputopts_ copts
                then withAttr ("border" <> "query") (str " ignoring balance assertions")
                else str "")
@@ -195,22 +190,20 @@ asDraw UIState{aopts=uopts@UIOpts{cliopts_=copts@CliOpts{reportopts_=ropts}}
                            f:_ -> str $ takeFileName f
                            -- [f,_:[]] -> (withAttr ("border" <> "bold") $ str $ takeFileName f) <+> str " (& 1 included file)"
                            -- f:fs  -> (withAttr ("border" <> "bold") $ str $ takeFileName f) <+> str (" (& " ++ show (length fs) ++ " included files)")
+            toggles = withAttr ("border" <> "query") $ str $ unwords $ concat [
+               [""]
+              ,if empty_ ropts then [] else ["nonzero"]
+              ,uiShowStatus copts $ statuses_ ropts
+              ,if real_ ropts then ["real"] else []
+              ]
             querystr = query_ ropts
             mdepth = depth_ ropts
-            togglefilters =
-              case concat [
-                   uiShowStatus copts $ statuses_ ropts
-                  ,if real_ ropts then ["real"] else []
-                  ] of
-                [] -> str ""
-                fs -> str " from " <+> withAttr ("border" <> "query") (str $ intercalate ", " fs) <+> str " txns"
-            nonzero | empty_ ropts = str ""
-                    | otherwise    = withAttr ("border" <> "query") (str " nonzero")
-            cur = str (case _asList s ^. listSelectedL of
-                        Nothing -> "-"
-                        Just i -> show (i + 1))
-            total = str $ show $ V.length nonblanks 
-            nonblanks = V.takeWhile (not . T.null . asItemAccountName) $ s ^. asList . listElementsL
+            curidx = case _asList s ^. listSelectedL of
+                       Nothing -> "-"
+                       Just i -> show (i + 1)
+            totidx = show $ V.length nonblanks 
+              where
+                nonblanks = V.takeWhile (not . T.null . asItemAccountName) $ s ^. asList . listElementsL
 
         bottomlabel = case mode of
                         Minibuffer ed -> minibuffer ed
@@ -285,6 +278,8 @@ asHandle ui0@UIState{
         VtyEvent (EvKey KEsc   []) -> continue $ closeMinibuffer ui
         VtyEvent (EvKey KEnter []) -> continue $ regenerateScreens j d $ setFilter s $ closeMinibuffer ui
                             where s = chomp $ unlines $ map strip $ getEditContents ed
+        VtyEvent (EvKey (KChar 'l') [MCtrl]) -> redraw ui
+        VtyEvent (EvKey (KChar 'z') [MCtrl]) -> suspend ui
         VtyEvent ev        -> do ed' <- handleEditorEvent ev ed
                                  continue $ ui{aMode=Minibuffer ed'}
         AppEvent _        -> continue ui
@@ -294,6 +289,8 @@ asHandle ui0@UIState{
     Help ->
       case ev of
         VtyEvent (EvKey (KChar 'q') []) -> halt ui
+        VtyEvent (EvKey (KChar 'l') [MCtrl]) -> redraw ui
+        VtyEvent (EvKey (KChar 'z') [MCtrl]) -> suspend ui
         _                    -> helpHandle ui ev
 
     Normal ->
@@ -346,7 +343,8 @@ asHandle ui0@UIState{
         VtyEvent (EvKey (KChar '/') []) -> continue $ regenerateScreens j d $ showMinibuffer ui
         VtyEvent (EvKey k           []) | k `elem` [KBS, KDel] -> (continue $ regenerateScreens j d $ resetFilter ui)
         VtyEvent e | e `elem` moveLeftEvents -> continue $ popScreen ui
-        VtyEvent (EvKey (KChar 'l') [MCtrl]) -> scrollSelectionToMiddle _asList >> invalidateCache >> continue ui
+        VtyEvent (EvKey (KChar 'l') [MCtrl]) -> scrollSelectionToMiddle _asList >> redraw ui
+        VtyEvent (EvKey (KChar 'z') [MCtrl]) -> suspend ui
 
         -- enter register screen for selected account (if there is one), 
         -- centering its selected transaction if possible
