@@ -20,7 +20,7 @@ import Data.Monoid
 #endif
 import Data.Time.Calendar (Day)
 import Data.Void (Void)
-import Graphics.Vty (Event(..),Key(..))
+import Graphics.Vty (Event(..),Key(..),Modifier(..))
 import Text.Megaparsec
 import Text.Megaparsec.Char
 
@@ -46,7 +46,8 @@ esInit _ _ _ = error "init function called with wrong screen type, should not ha
 esDraw :: UIState -> [Widget Name]
 esDraw UIState{aopts=UIOpts{cliopts_=copts@CliOpts{}}
               ,aScreen=ErrorScreen{..}
-              ,aMode=mode} =
+              ,aMode=mode
+              } =
   case mode of
     Help       -> [helpDialog copts, maincontent]
     -- Minibuffer e -> [minibuffer e, maincontent]
@@ -74,16 +75,18 @@ esDraw UIState{aopts=UIOpts{cliopts_=copts@CliOpts{}}
 esDraw _ = error "draw function called with wrong screen type, should not happen"
 
 esHandle :: UIState -> BrickEvent Name AppEvent -> EventM Name (Next UIState)
-esHandle ui@UIState{
-   aScreen=ErrorScreen{..}
-  ,aopts=UIOpts{cliopts_=copts}
-  ,ajournal=j
-  ,aMode=mode
-  } ev =
+esHandle ui@UIState{aScreen=ErrorScreen{..}
+                   ,aopts=UIOpts{cliopts_=copts}
+                   ,ajournal=j
+                   ,aMode=mode
+                   }
+         ev =
   case mode of
     Help ->
       case ev of
         VtyEvent (EvKey (KChar 'q') []) -> halt ui
+        VtyEvent (EvKey (KChar 'l') [MCtrl]) -> redraw ui
+        VtyEvent (EvKey (KChar 'z') [MCtrl]) -> suspend ui
         _                    -> helpHandle ui ev
 
     _ -> do
@@ -104,6 +107,8 @@ esHandle ui@UIState{
 --             Left err -> continue ui{aScreen=s{esError=err}} -- show latest parse error
 --             Right j' -> continue $ regenerateScreens j' d $ popScreen ui  -- return to previous screen, and reload it
         VtyEvent (EvKey (KChar 'I') []) -> continue $ uiCheckBalanceAssertions d (popScreen $ toggleIgnoreBalanceAssertions ui)
+        VtyEvent (EvKey (KChar 'l') [MCtrl]) -> redraw ui
+        VtyEvent (EvKey (KChar 'z') [MCtrl]) -> suspend ui
         _ -> continue ui
 
 esHandle _ _ = error "event handler called with wrong screen type, should not happen"
@@ -171,8 +176,8 @@ uiCheckBalanceAssertions d ui@UIState{aopts=UIOpts{cliopts_=copts}, ajournal=j}
   | ignore_assertions_ $ inputopts_ copts = ui
   | otherwise =
     case journalCheckBalanceAssertions j of
-      Right _  -> ui
-      Left err ->
+      Nothing  -> ui
+      Just err ->
         case ui of
           UIState{aScreen=s@ErrorScreen{}} -> ui{aScreen=s{esError=err}}
           _                                -> screenEnter d errorScreen{esError=err} ui
