@@ -24,7 +24,8 @@ import Data.Time.Calendar
 import qualified Data.Vector as V
 import Graphics.Vty (Event(..),Key(..),Modifier(..))
 import Brick
-import Brick.Widgets.List hiding (reverse)
+import Brick.Widgets.List
+  (handleListEvent, list, listElementsL, listMoveDown, listMoveTo, listNameL, listSelectedElement, listSelectedL, renderList)
 import Brick.Widgets.Edit
 import Lens.Micro.Platform
 import Safe
@@ -133,9 +134,9 @@ rsInit _ _ _ = error "init function called with wrong screen type, should not ha
 
 rsDraw :: UIState -> [Widget Name]
 rsDraw UIState{aopts=uopts@UIOpts{cliopts_=copts@CliOpts{reportopts_=ropts}}
-                            ,aScreen=RegisterScreen{..}
-                            ,aMode=mode
-                            } =
+              ,aScreen=RegisterScreen{..}
+              ,aMode=mode
+              } =
   case mode of
     Help       -> [helpDialog copts, maincontent]
     -- Minibuffer e -> [minibuffer e, maincontent]
@@ -281,6 +282,8 @@ rsHandle ui@UIState{
         VtyEvent (EvKey KEsc   []) -> continue $ closeMinibuffer ui
         VtyEvent (EvKey KEnter []) -> continue $ regenerateScreens j d $ setFilter s $ closeMinibuffer ui
                             where s = chomp $ unlines $ map strip $ getEditContents ed
+        VtyEvent (EvKey (KChar 'l') [MCtrl]) -> redraw ui
+        VtyEvent (EvKey (KChar 'z') [MCtrl]) -> suspend ui
         VtyEvent ev              -> do ed' <- handleEditorEvent ev ed
                                        continue $ ui{aMode=Minibuffer ed'}
         AppEvent _        -> continue ui
@@ -290,6 +293,8 @@ rsHandle ui@UIState{
     Help ->
       case ev of
         VtyEvent (EvKey (KChar 'q') []) -> halt ui
+        VtyEvent (EvKey (KChar 'l') [MCtrl]) -> redraw ui
+        VtyEvent (EvKey (KChar 'z') [MCtrl]) -> suspend ui
         _                    -> helpHandle ui ev
 
     Normal ->
@@ -333,7 +338,8 @@ rsHandle ui@UIState{
         VtyEvent (EvKey (KLeft)     [MShift]) -> continue $ regenerateScreens j d $ previousReportPeriod journalspan ui
         VtyEvent (EvKey k           []) | k `elem` [KBS, KDel] -> (continue $ regenerateScreens j d $ resetFilter ui)
         VtyEvent e | e `elem` moveLeftEvents  -> continue $ popScreen ui
-        VtyEvent (EvKey (KChar 'l') [MCtrl]) -> scrollSelectionToMiddle rsList >> invalidateCache >> continue ui
+        VtyEvent (EvKey (KChar 'l') [MCtrl]) -> scrollSelectionToMiddle rsList >> redraw ui
+        VtyEvent (EvKey (KChar 'z') [MCtrl]) -> suspend ui
 
         -- enter transaction screen for selected transaction
         VtyEvent e | e `elem` moveRightEvents -> do
