@@ -17,7 +17,7 @@ import Data.Monoid
 #endif
 import qualified Data.Text as T
 import Data.Time.Calendar (Day)
-import Graphics.Vty (Event(..),Key(..))
+import Graphics.Vty (Event(..),Key(..),Modifier(..))
 import Brick
 import Brick.Widgets.List (listMoveTo)
 
@@ -49,11 +49,12 @@ tsInit _ _ _ = error "init function called with wrong screen type, should not ha
 
 tsDraw :: UIState -> [Widget Name]
 tsDraw UIState{aopts=UIOpts{cliopts_=copts@CliOpts{reportopts_=ropts}}
-                              ,aScreen=TransactionScreen{
-                                   tsTransaction=(i,t)
-                                  ,tsTransactions=nts
-                                  ,tsAccount=acct}
-                              ,aMode=mode} =
+              ,aScreen=TransactionScreen{tsTransaction=(i,t)
+                                        ,tsTransactions=nts
+                                        ,tsAccount=acct
+                                        }
+              ,aMode=mode
+              } =
   case mode of
     Help       -> [helpDialog copts, maincontent]
     -- Minibuffer e -> [minibuffer e, maincontent]
@@ -106,17 +107,20 @@ tsDraw _ = error "draw function called with wrong screen type, should not happen
 
 tsHandle :: UIState -> BrickEvent Name AppEvent -> EventM Name (Next UIState)
 tsHandle ui@UIState{aScreen=s@TransactionScreen{tsTransaction=(i,t)
-                                                ,tsTransactions=nts
-                                                ,tsAccount=acct}
-                    ,aopts=UIOpts{cliopts_=copts@CliOpts{reportopts_=ropts}}
-                    ,ajournal=j
-                    ,aMode=mode
-                    }
+                                               ,tsTransactions=nts
+                                               ,tsAccount=acct
+                                               }
+                   ,aopts=UIOpts{cliopts_=copts@CliOpts{reportopts_=ropts}}
+                   ,ajournal=j
+                   ,aMode=mode
+                   }
          ev =
   case mode of
     Help ->
       case ev of
         VtyEvent (EvKey (KChar 'q') []) -> halt ui
+        VtyEvent (EvKey (KChar 'l') [MCtrl]) -> redraw ui
+        VtyEvent (EvKey (KChar 'z') [MCtrl]) -> suspend ui
         _                    -> helpHandle ui ev
 
     _ -> do
@@ -176,6 +180,8 @@ tsHandle ui@UIState{aScreen=s@TransactionScreen{tsTransaction=(i,t)
           where
             ui'@UIState{aScreen=scr} = popScreen ui
             ui'' = ui'{aScreen=rsSelect (fromIntegral i) scr}
+        VtyEvent (EvKey (KChar 'l') [MCtrl]) -> redraw ui
+        VtyEvent (EvKey (KChar 'z') [MCtrl]) -> suspend ui
         _ -> continue ui
 
 tsHandle _ _ = error "event handler called with wrong screen type, should not happen"
