@@ -21,6 +21,8 @@ module Hledger.UI.UIUtils (
   ,renderToggle
   ,replaceHiddenAccountsNameWith
   ,scrollSelectionToMiddle
+  ,suspend
+  ,redraw
 )
 where
 
@@ -29,14 +31,17 @@ import Brick.Widgets.Border
 import Brick.Widgets.Border.Style
 import Brick.Widgets.Dialog
 import Brick.Widgets.Edit
-import Brick.Widgets.List hiding (reverse)
+import Brick.Widgets.List (List, listSelectedL, listNameL, listItemHeightL)
 import Control.Monad.IO.Class
 import Data.List
 import Data.Maybe
 #if !(MIN_VERSION_base(4,11,0))
 import Data.Monoid
 #endif
-import Graphics.Vty (Event(..),Key(..),Modifier(..),Color,Attr,currentAttr)
+import Graphics.Vty
+  (Event(..),Key(..),Modifier(..),Vty(..),Color,Attr,currentAttr,refresh
+  -- ,Output(displayBounds,mkDisplayContext),DisplayContext(..)
+  )
 import Lens.Micro.Platform
 import System.Environment
 
@@ -46,8 +51,27 @@ import Hledger.Cli.DocFiles
 import Hledger.UI.UITypes
 import Hledger.UI.UIState
 
+-- | On posix platforms, send the system STOP signal to suspend the
+-- current program. On windows, does nothing.
+#ifdef mingw32_HOST_OS
+suspendSignal :: IO ()
+suspendSignal = return ()
+#else
+import System.Posix.Signals
+suspendSignal :: IO ()
+suspendSignal = raiseSignal sigSTOP 
+#endif
 
--- ui
+-- | On posix platforms, suspend the program using the STOP signal,
+-- like control-z in bash, returning to the original shell prompt,
+-- and when resumed, continue where we left off.
+-- On windows, does nothing.
+suspend :: s -> EventM a (Next s)
+suspend st = suspendAndResume $ suspendSignal >> return st
+
+-- | Tell vty to redraw the whole screen, and continue.
+redraw :: s -> EventM a (Next s)
+redraw st = getVtyHandle >>= liftIO . refresh >> continue st
 
 -- | Wrap a widget in the default hledger-ui screen layout.
 defaultLayout :: Widget Name -> Widget Name -> Widget Name -> Widget Name
@@ -66,7 +90,7 @@ helpDialog _copts =
     render $
       withDefAttr "help" $
       renderDialog (dialog (Just "Help (?/LEFT/ESC to close)") Nothing (c^.availWidthL)) $ -- (Just (0,[("ok",())]))
-      padAll 1 $
+      padTop (Pad 1) $ padLeft (Pad 1) $ padRight (Pad 1) $
         vBox [
            hBox [
               padRight (Pad 1) $
@@ -112,8 +136,9 @@ helpDialog _copts =
                   ,renderKey ("A   ", "add transaction (hledger-iadd)")
                   ,renderKey ("E   ", "open editor")
                   ,renderKey ("I   ", "toggle balance assertions")
-                  ,renderKey ("C-l ", "redraw & recenter")
                   ,renderKey ("g   ", "reload data")
+                  ,renderKey ("C-l ", "redraw & recenter")
+                  ,renderKey ("C-z ", "suspend")
                   ,renderKey ("q   ", "quit")
                 ]
              ]
@@ -165,7 +190,7 @@ borderQueryStr qry = str " matching " <+> withAttr ("border" <> "query") (str qr
 
 borderDepthStr :: Maybe Int -> Widget Name
 borderDepthStr Nothing  = str ""
-borderDepthStr (Just d) = str " to " <+> withAttr ("border" <> "query") (str $ "depth "++show d)
+borderDepthStr (Just d) = str " to depth " <+> withAttr ("border" <> "query") (str $ show d)
 
 borderPeriodStr :: String -> Period -> Widget Name
 borderPeriodStr _           PeriodAll = str ""
